@@ -293,6 +293,11 @@ class VoiceServerTransport(Transport):
 
         client_addr = message['to_addr']
         client = self._clients.get(client_addr)
+        if client is None:
+            yield self.publish_nack(
+                message["message_id"],
+                "Client %r no longer connected" % (client_addr,))
+            return
 
         text = text.encode('utf-8')
         overrideURL = None
@@ -311,3 +316,5 @@ class VoiceServerTransport(Transport):
 
         if message['session_event'] == TransportUserMessage.SESSION_CLOSE:
             client.close_call()
+
+        yield self.publish_ack(message["message_id"], message["message_id"])
